package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````*!\```````!``````````%BA````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````$B/````````2(\`````````
M``$```````$````&````F)L```````"8FP$``````)B;`0``````X`0`````
M```X%0```````````0```````@````8```"HFP```````*B;`0``````J)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````%R)````````
M7(D```````!<B0```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"8FP```````)B;`0``````F)L!``````!H!```````
M`&@$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!+````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$L```!,````4````%4```!6````70```%X```!?`````````&$`
M``!B`````````&,```!D````9P```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`(`9
M`````````````````````````P`2``"@`0`````````````````!````$@``
M```````````````````````)````$0````````````````````````#5`0``
M$0````````````````````````!Q`0``$@`````````````````````````0
M````$@````````````````````````"N`0``$@``````````````````````
M```8````$@`````````````````````````?````$@``````````````````
M``````#B`0``$@````````````````````````"Z`0``$@``````````````
M```````````H````(`````````````````````````#Q`@``(0``````````
M``````````````!`````$@````````````````````````!&````$@``````
M``````````````````!-````$@````````````````````````"^`@``$@``
M``````````````````````"O`@``$@````````````````````````!4````
M$@`````````````````````````(`@``$@````````````````````````!;
M````$@````````````````````````".`@``$@``````````````````````
M``!B````$@````````````````````````!J````$@``````````````````
M``````!W`@``$@````````````````````````!R````$@``````````````
M``````````!X````$@````````````````````````"!````(```````````
M``````````````"H`@``$@````````````````````````"=````$@``````
M``````````````````"B````$@````````````````````````#S`0``$0``
M``````````````````````"5`@``$@`````````````````````````U`@``
M$@````````````````````````"I````$@`````````````````````````G
M`@``$@`````````````````````````W`P``$@``````````````````````
M``#P`@``$0````````````````````````!9`@``$@``````````````````
M``````#=`@``$@````````````````````````#R`@``$0``````````````
M``````````"P````$@````````````````````````#5`@``$@``````````
M``````````````"Y````$0````````````````````````!_`0``$@``````
M``````````````````#+````(@````````````````````````#:````(```
M``````````````````````#P````$@````````````````````````"@`@``
M$@````````````````````````!%`@``$@````````````````````````#U
M````$@````````````````````````#[````(```````````````````````
M``""`@``$@`````````````````````````5`0``$@``````````````````
M``````"?`0``$@`````````````````````````:`0``$@``````````````
M``````````!G`@``$@````````````````````````".`0``$@``````````
M```````````````@`0``$@`````````````````````````Q`0``$@``````
M```````````````````#`@``$@````````````````````````!S````$@``
M```````````````````````4`@``$@````````````````````````!.`@``
M$@````````````````````````#.`@``$@`````````````````````````W
M`0``$@````````````````````````#&`@``$@``````````````````````
M``!+`0``$@````````````````````````#^`0``$@``````````````````
M``````!2`0``$@````````````````````````!9`0``$@``````````````
M``````````#O`@``(0````````````````````````!J`0``$@``````````
M```````````````W!```$``3`-"P`0````````````````#J`@``$@`)`&`=
M````````R`$```````#/`0``$@`*`!1*````````!`````````!Y`P``$@`)
M`%PM````````#`8```````!'!```$@`)`)PU````````9`````````!6`P``
M$@`)`(PG````````!`````````#K`P``$@`'`(`9````````!`````````"<
M`P``$@`)`&@S````````-`(```````#Q`P``$``3`'B@`0``````````````
M```?!```$@`)`)`G````````V`$```````#4`P``$``3`'B@`0``````````
M``````!G`P``$@`)`*@L````````M`````````"&`P``$@`)`,PE````````
M.`````````".`P``$@`)`#`L````````6`````````"R`P``$@`)`"!'````
M````8`$```````#'`P``$@`)`&@I````````(`````````#@`P``$``3`-"P
M`0````````````````!"!```$``3`-"P`0`````````````````<`P``$@`)
M`$0?````````*`````````#_`P``$@`)`(@I````````"`$```````"]`P``
M$0`2`'"@`0``````"``````````8!```$``2`'B@`0````````````````#9
M`P``$@`)`"@?``````````````````#H`P``$@`)`,1&````````7```````
M```E`P``$@`)`(@L````````(`````````!``P``$@`)`%@F````````-`$`
M```````L!```$@`)`(!(````````E`$````````V!```$``3`-"P`0``````
M```````````+!```$@`)`)`J````````H`$`````````;W!E;F1I<@!S=&1E
M<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE
M7VEN9F\`;'-E96L`9V5T<&ED`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO
M=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L
M;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?
M8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF
M;P!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R
M;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF
M:6,`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME
M>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E
M<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W
M6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!0
M97)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!F<')I;G1F`'-T<F1U<`!P
M=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`
M7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N
M;75S;"UA87)C:#8T+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X
M96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R
M7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M
M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`%]?96YD7U\`<VAA
M7VEN:70`7U]B<W-?<W1A<G1?7P!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`
M7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`7U]B<W-?96YD7U\`7V5N
M9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``
M````````F)L!```````#!````````$`@````````H)L!```````#!```````
M`.`?````````@)\!```````#!````````&`=````````F)\!```````#!```
M`````!1*````````L)\!```````#!````````(`9`````````*`!```````#
M!`````````"@`0``````$*`!```````#!````````-5,````````&*`!````
M```#!````````"5*````````**`!```````#!`````````9+````````,*`!
M```````#!````````/]*````````.*`!```````#!````````,E,````````
M0*`!```````#!````````!Q+````````2*`!```````#!````````-%,````
M````6*`!```````#!````````+M,````````8*`!```````#!````````,!,
M````````<*`!```````#!````````-I,````````B)\!```````!!```!```
M````````````D)\!```````!!```!0``````````````H)\!```````!!```
M#0``````````````J)\!```````!!```'0``````````````N)\!```````!
M!```(0``````````````P)\!```````!!```*@``````````````R)\!````
M```!!```+0``````````````T)\!```````!!```+P``````````````V)\!
M```````!!```,```````````````X)\!```````!!```-0``````````````
MZ)\!```````!!```.@``````````````\)\!```````!!```.P``````````
M````^)\!```````!!```0```````````````H)T!```````"!````P``````
M````````J)T!```````"!```!@``````````````L)T!```````"!```!P``
M````````````N)T!```````"!```"```````````````P)T!```````"!```
M"0``````````````R)T!```````"!```"@``````````````T)T!```````"
M!```"P``````````````V)T!```````"!```#```````````````X)T!````
M```"!```#0``````````````Z)T!```````"!```#P``````````````\)T!
M```````"!```$```````````````^)T!```````"!```$0``````````````
M`)X!```````"!```$@``````````````")X!```````"!```$P``````````
M````$)X!```````"!```%```````````````&)X!```````"!```%0``````
M````````()X!```````"!```%@``````````````*)X!```````"!```%P``
M````````````,)X!```````"!```&```````````````.)X!```````"!```
M&0``````````````0)X!```````"!```&@``````````````2)X!```````"
M!```&P``````````````4)X!```````"!```'```````````````6)X!````
M```"!```'@``````````````8)X!```````"!```'P``````````````:)X!
M```````"!```(```````````````<)X!```````"!```(@``````````````
M>)X!```````"!```(P``````````````@)X!```````"!```)```````````
M````B)X!```````"!```)0``````````````D)X!```````"!```)@``````
M````````F)X!```````"!```*```````````````H)X!```````"!```*0``
M````````````J)X!```````"!```*P``````````````L)X!```````"!```
M+```````````````N)X!```````"!```+@``````````````P)X!```````"
M!```+P``````````````R)X!```````"!```,```````````````T)X!````
M```"!```,0``````````````V)X!```````"!```,@``````````````X)X!
M```````"!```,P``````````````Z)X!```````"!```-```````````````
M\)X!```````"!```-@``````````````^)X!```````"!```-P``````````
M`````)\!```````"!```.```````````````")\!```````"!```.0``````
M````````$)\!```````"!```/```````````````&)\!```````"!```/0``
M````````````()\!```````"!```/@``````````````*)\!```````"!```
M/P``````````````,)\!```````"!```00``````````````.)\!```````"
M!```0@``````````````0)\!```````"!```0P``````````````2)\!````
M```"!```1```````````````4)\!```````"!```10``````````````6)\!
M```````"!```1@``````````````8)\!```````"!```1P``````````````
M:)\!```````"!```2```````````````<)\!```````"!```2@``````````
M````_7N_J?T#`)']>\&HP`-?UO![OZG0``"0$<Y&^1!B-I$@`A_6'R`#U1\@
M`]4?(`/5T```D!'21OD0@C:1(`(?UM```)`1UD;Y$*(VD2`"'];0``"0$=I&
M^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1XD;Y$`(WD2`"'];0``"0
M$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM```)`1[D;Y$&(WD2`"'];0
M``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?UM```)`1^D;Y$,(WD2`"
M'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?UM```)`1!D?Y$"(X
MD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D08CB1(`(?UM```)`1$D?Y
M$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:1_D0PCB1(`(?UM```)`1
M'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```D!$F1_D0(CF1(`(?UM``
M`)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6T```D!$R1_D0@CF1(`(?
MUM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@`A_6T```D!$^1_D0XCF1
M(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@`A_6T```D!%*1_D0
M0CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'^1"".I$@`A_6T```D!%6
M1_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0$5Y'^1#B.I$@`A_6T```
MD!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0``"0$6I'^1!".Y$@`A_6
MT```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"'];0``"0$79'^1"B.Y$@
M`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"'];0``"0$8)'^1`"
M/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y$$(\D2`"'];0``"0$8Y'
M^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1ED?Y$*(\D2`"'];0``"0
M$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM```)`1HD?Y$`(]D2`"'];0
M``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?UM```)`1KD?Y$&(]D2`"
M'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1(`(?UM```)`1ND?Y$,(]
MD2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GBAP.IXN,`D>$#`9'@3P"Y
MX#,!D97__Y?"``"0P```D$+\1_D`^$?YX0,"JC?__Y?```"0`,A'^0``0#F`
M`0`U9O__EV+"`I%`#`#Y8```M2``@%*1__^7J/__EX#>1_D``$"YQ?__EQ_<
M*#F4WD?Y@`)`N<'__Y<!*%(Y(0`?,@$H$CF``D"YO/__EP$H4CDA```R`2@2
M.>!/0+D4#``1`!``$0!\?9.,__^7Y"-`^>,#`*I@P@*1XD]`N0,$`/F``$#Y
M8```^0```/``U#*18`0`^<```+``.$#Y8`@`^0```/``X#*18`P`^0``@-(!
M$``1``0`D25\?9-AS"&+7P``:PP%`%1UP@*1/P``^>(#%"H$`(#2`0``L"$0
M&)&@#D#Y%?__E_0#`"J````UH`Y`^6'__Y?T`P`J=<("D:`.0/DY__^7````
M\`#D*I&:``"48`$`M:`*0/F@``"U````\`"X*9&4``"4H`H`^6#"`I$`"$#Y
M0```M*H%`)1SP@*18`Y`^8C__Y>O_O^7X`,4*O-30:GU$T#Y_7O%J,`#7]:!
M>&#X86@E^-'__Q<=`(#2'@"`TN`#`)'!``"0(:`ND1_L?)(!```4X@,`JL0`
M`)##``"0P```D(3,1_D%`(#28]A'^0#`1_E!A$#X$O__%Q\@`]7```"P`.`!
MD<$``+`AX`&1/P``Z\```%3!``"0(=1'^6$``+3P`P&J``(?UL`#7];```"P
M`.`!D<$``+`AX`&1(0``RR+\?]-!#(&+(?Q!D\$``+3"``"00O!'^6(``+3P
M`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#YTP``L&#B03D``@`UP```D`#H
M1_F```"TP```D```0/GY_O^7V/__EZ```/``T$?Y@```M"```-``0"F1@O[_
MER``@%)@X@$Y\PM`^?U[PJC``U_6H```\`#L1_E``0"T_7N_J<$``)`@``#0
M_0,`D2$``I$`0"F1Y_[_E_U[P:C-__\7S/__%_U[O*G]`P"1\U,!J?5;`JGW
M8P.I``4`M/8#`*J@``#P`.!'^1<`0/EW!`"T^`,!JN(#%JI``$`Y'_0`<008
M0'HA`P!40@`62_4#%ZI3?$"3M`)`^=0!`+3B`Q.JX0,6JN`#%*J"_O^7(`(`
M-8!J<S@?]`!QP0$`5+4"%\MS!@"1E`(3B[7^0Y,5`P"YX`,4JO-30:GU6T*I
M]V-#J?U[Q*C``U_60@0`D>/__Q>U(@"1Z/__%Q0`@-+U__\7_7N^J:$``/#]
M`P"1(>1'^2(`0/GB#P#Y`@"`TN%3`)')__^7H0``\"'D1_GC#T#Y(@!`^6,`
M`NL"`(#20```5/3^_Y?]>\*HP`-?UOU[O*G]`P"1\U,!J?,#`*J@``#PM```
M\/43`/D`Y$?Y]=,`D93B1_D!`$#YX1\`^0$`@-+A`Q6JX`,3JJ___Y<@`0"U
MH```\`#D1_GB'T#Y`0!`^4(``>L!`(#20`$`5-G^_Y>``D#YXC>`N0(,`HM`
M!$#Y0```^>#]_[1"(`"1_/__%_-30:GU$T#Y_7O$J,`#7];]>[*IH0``\/T#
M`)$AY$?Y\U,!J?5;`JGW8P.I^2,`^2(`0/GB;P#Y`@"`TH`"`+0!`$`Y]`,`
MJB$"`#39_?^7]@,`JL`!`+07``#0&```T/>6*)$8DRB1&0``T.`#%JH`_O^7
M\P,`JJ`!`+7@`Q:J)/[_E^`#%*I^_O^7H```\`#D1_GB;T#Y`0!`^4(``>L!
M`(#20`4`5*;^_Y=S3@"1X0,7JN`#$ZKJ_?^7@/W_-.$#&*K@`Q.JYOW_EP#]
M_S3@`Q2JE_[_E_4#`*K@`Q.JE/[_E[4"``NU"@`1H'Y`D_3]_Y?C`Q.JX@,4
MJO4#`*HAGRB1?_[_E^%C`9'@`Q6J;/[_EQ\$`#%``0!4X&M`N0`,%!(?$$!Q
MP0``5.`#%:JX__^7X`,5JE[^_Y?,__\7X`,5JMO]_Y?[__\7\U-!J?5;0JGW
M8T.I^2-`^?U[SJC``U_6_7NUJ:$``/#]`P"1(>1'^?,+`/GS`P"J(@!`^>)7
M`/D"`(#2X:,`D=W]_Y>``@`UX3M`N0(`E%(A#!02/Q!`<2000GK!``!4X`,3
MJD$`@%*/_?^7'P``<>`7GQJA``#P(>1'^>-70/DB`$#Y8P`"ZP(`@-*```!4
M6?[_EP``@%+W__\7\PM`^?U[RZC``U_6_7NZJ?T#`)'U6P*I]0,`JJ```/#S
M4P&I\P,!J@#D1_GW8P.I^2,`^0$`0/GA+P#Y`0"`TF`"0#D?]`!Q00``5',&
M`)'@`Q.J/?[_E^%3`9'V`P"JX`,5J@K__Y?T`P"J(`(`M#;^_Y??`@#KZ`0`
M5`$`@-)@:F$X@&HA."$$`)&@__\UH```\`#D1_GB+T#Y`0!`^4(``>L!`(#2
M(`D`5"O^_Y>T``#P@.)'^1D`0/D``(#2(B,`T?<#`"H`!`"107A@^*'__[7!
M``"0X`H`$2*P0+D`?'V3H@4`-.$#`*K@`QFJ/OW_EX'B1_D@``#YH/S_M)3B
M1_GA!@`1]U<`N8`"0/D?V"'XX0,5JB``0#D?]`!Q!!A`>@$%`%2W``#P]%>`
MN2$`%<O`"@"1]^)'^93R?=,`P"&+^`)`^63]_Y<`:S3X`/K_M.`"0/D!:'3X
MX@,!JJ`60#@A!`"1(/`?.&```#0?]`!Q0?__5*`'@%)````Y``"`TF)J8#@B
M:"`X``0`D:+__S6___\7(@"`4B*P`+E._?^7^`,`JD#W_[3B?GV3X0,9JDW]
M_Y>`XD?Y&```^=#__Q<A!`"1U/__%_-30:GU6T*I]V-#J?DC0/G]>\:HP`-?
MUOU[OZF@``#P_0,`D0#<1_D``$"YQ/W_E_U[P:BB``#P(P``T`$``-!"]$?Y
M8\`DD2&T*)&T_?\7_7N^J?T#`)'S"P#YLP``\'/>1_E@`D"YM?W_E^O__Y=@
M`D"YLOW_E_,+0/D$``#0_7O"J(30,I'C`P2J!0"`4@(``+`!``#00J`-D2$D
M*9'O_/\7#`J$TO]C+,N@``#P_7L`J?T#`)$`Y$?Y\U,!J?3C`)'U$P#Y`0!`
M^>$G$/D!`(#2\OS_E^,#`"H$``#0`@``T(1X*9%"B"F1X`,4JB$`@M+6_/^7
M'P0`,4$!`%0#`(#2H```\`#D1_GB)U#Y`0!`^4(``>L!`(#2``4`5)O]_Y<`
M?$"3'P1`\4D``%0`?2#4``B"TO-C((OA`Q.JX`,4J@(`@M(Q_?^7]`,`JH#]
M_S<`!``1`'Q`D^S\_Y?C`P"JX/S_M)5^0),?`!/K@@``5```%8M_`@#KH_W_
M5'\`$^N)``!48`(5BW\``.L#_?]4(`""4I\"`&NL_/]4X`,#JN(#%:KA`Q.J
M;/W_E^,#`*H?:#4XT___%^`#`ZH,"H32_7M`J?-30:GU$T#Y_V,LB\`#7]:S
M__\7#!R"TO]C+,O]>P"I_0,`D?-3`:GT`P"JH```\/5;`JGS`P&J`.1'^?=C
M`ZGY:P2I`0!`^>%O"/D!`(#2````T`"X*9%7_O^7]@,`JN$%@%+@`Q2JX_S_
MEZ`!`+0```#0X0,4J@#<*9'__O^7H```\`#D1_GB;TCY`0!`^4(``>L!`(#2
M@`D`5$K]_Y?@`Q2J1/W_E_<#`"K@`Q.JO?S_EQ@``-`9``#0`1,JD1H``-`H
M_?^7.9<HD?,#`*I:&RJ1]6,#D=/\_[1@`D`Y'P``<7,2F9I6`0"TX0,3JN`#
M%JI\_/^7P```-0$3*I$``(#2&/W_E_,#`*KS__\7X`,3JBC]_Y<!!`!1(WQ`
MDV+*83A?O`!Q(`(`5.$&`!$@```+'_P_<<SY_U3E`Q2JY`,:JN,#$ZK@`Q6J
M`@``T`$`@M)"B"V12_S_EP`$`!$?!$!QJ0``5`!](-3@`P$J?VHC..G__Q?A
M8P&1X`,5JO'\_Y?`^_\UX&M`N0`,%!(?($!Q0?O_5.`#%:HA`(!2-?S_E\#Z
M_S7A`Q6J````T`#<*9&Q_O^7X`,5JGK\_Y?T`P"JK___%^`#%*H,'(+2_7M`
MJ?-30:GU6T*I]V-#J?EK1*G_8RR+P`-?UN$#`*HB`$`Y0@``-<`#7]8A!`"1
M7[P`<0`0@9KZ__\7X`<`M/U[OJG]`P"1\U,!J?,#`*H!`$`YP0``-0```-``
ME"B1\U-!J?U[PJA;_/\7WOS_EP($`-%B`@*+?P("ZX(#`%1``$`Y'[P`<:`"
M`%1_`@+KX@(`5.`#`JH!]%\X/[P`<2$"`%1"!`#1?P("ZX(``%1``$`Y'[P`
M<6#__U1"`!/+0`@`D1\$0/%(`P!40@0`D5\$0/')`0!4`'T@U$($`-'F__\7
MX@,`JNG__Q=_`@+KH?W_5&`"0#D?O`!QX/K_5````-``&"J1UO__%]0``)"4
M0@.1X0,3JN`#%*I:_/^7X`,4JO-30:G]>\*HP`-?U@``@-+\__\7````T`"4
M*)'*__\7_7NZJ:```/#]`P"1`.1'^?-3`:D4``#0]5L"J14``-`6``#0`0!`
M^>$O`/D!`(#2(```T`#`))'APP"1`"@`D1,``-!S/BN1``1`K0!`0'D@0`!Y
M````T``@*I$@!`"MH_W_EP```-``1"J1H/W_EP```-``9"J1G?W_EP```-``
MB"J1FOW_EZ"F*I&8_?^7````T`#D*I&5_?^7P+HID9/]_Y>`%BN1D?W_E^`#
M$ZJ/_?^7````T`!D*Y&,_?^7````T`#<*9&)_?^7````T`",*Y%S_?^7@```
MM.$#`*K@`Q.J(/[_EP```-``T"N1;/W_E^$#`*J```"T````T``8+)$8_O^7
M````T`!$+)%D_?^7X0,`JN`!`+3`NBF1$?[_EZ"F*I$!``#0(?0LD0W^_Y>@
M``#P`.1'^>(O0/D!`$#Y0@`!ZP$`@-(@`@!46/S_EP```-``A"R14?W_E^$#
M`*I@``"T@!8KD>W__Q<!``#0X`<!D2'(+)%"`8#2M/O_EP#]_S7A+P&1]___
M%_-30:GU6T*I_7O&J,`#7];]>[ZI_0,`D?,+`/G3``"08`I`N1\$`#%!`0!4
M````T``4*Y$W_?^70`$`M```0#D``0`T'\``<>`'GQI@"@"Y8`I`N?,+0/G]
M>\*HP`-?U@``@%+Z__\7_7N_J?T#`)$P_/^7O_O_ET```+0``$#Y_7O!J,`#
M7];]>[VI_0,`D?5;`JD5``#0MOXLD?-3`:GS`P"JX`,6JAK]_Y>```"T`0!`
M.?0#`*KA```UX0,3JJ#^+)'S4T&I]5M"J?U[PZC!_?\7X0,3JI+[_Y>``@"U
MX`,3J@O\_Y?U`P"JX`,4J@C\_Y>@`@"+``@`D6G[_Y?D`Q2J]0,`JN(#$ZH#
M``#0`0``T&,0*I$AB"V1\?O_E^$#%:K@`Q:JY___%_-30:GU6T*I_7O#J,`#
M7]8,,I#2_V,LR^$C0)']>P"I_0,`D?5;`JGU`P"JH```\/-3`:GT0P*1%@``
MT`#D1_GW8P.I^6L$J?LK`/D"`$#Y(L0`^0(`@-+```"0`"``D0$,0/GA.P#Y
M`8``D0*,0*GB#P:I(`1`K0(,1:GBCP>I@`8`K2`(P#T`,$#YX$<`^<"Z*9'@
M+X`]T_S_EP`#`+0!`$`Y\P,`JJ$"`#2L__^7H```\.(C0)$`Y$?Y0\1`^0$`
M0/EC``'K`0"`TD```%3)^_^7X`,3J@PRD-+]>T"I\U-!J?5;0JGW8T.I^6M$
MJ?LK0/G_8RR+-_O_%Y#__Y?S`P"J``(`M??C`9'@`D#Y@```M1,``-!S/BV1
M"@``%+'\_Y=@``"U]R(`D?C__Q<!`$`YH?__-"?[_Y?S`P"J0/__M.`#$ZJG
M^_^7`/A_TQ@``-``!`"1&%LMD0;[_Y?Y`P"J]P,`JF("0#F""0`UDP)`^9,!
M`+3@`Q.JFOS_E_,#`*J`"0"T`0!`.4$)`#0B_?^7``D`-.`#$ZH.^_^7\P,`
MJO>#`9&S``"U]`)`^70``+2``D`Y(`@`->`#$ZJ)^_^7]P,`JN`#&:J&^_^7
M]P(`"_<2$!$8``#0]WY`D^`#%ZKD^O^7Y0,9J@,;*I'B`Q.J!```T(1L+9'T
M`P"J`0``T"&`+9%K^_^7X`,4J@$X@%)0^_^7'P0`,0$&`%1)^_^7!`!`N9]$
M`'&`!0!4H```\`$``-"B`D#YXP,4J@#$1_DAI"V1``!`^2+[_Y<3`(#2H```
M\.(C0)$`Y$?Y0\1`^0$`0/EC``'K`0"`T@'S_U3@`Q.J##*0TOU[0*GS4T&I
M]5M"J?=C0ZGY:T2I^RM`^?]C+(O``U_6X`,7JN$#&*IS!@"1]PH`D4+[_Y>N
M__\7E"(`D:[__Q?@`Q2JUOS_EX```#3@`Q2JPOK_E_,#`*KW(@"1M/__%^$#
M`Y'@`Q2JM/K_E_D#`"I``0`TH```T.,#%*JB`D#Y`0``L`#$1_DAD"Z1``!`
M^?+Z_Y?0__\7X--`N0`,%!(?$$!Q@?[_5//;0+DW^_^7?P(`:P'^_U3@TT"Y
M`"``$A\`!W&!_?]4X`,7JHOZ_Y?S`P"J````L``H+9$C_/^7X0,`JD`+`+6W
M`D#YX`,7JA[[_Y?Z`P"J'PP`<6T#`%0`?$"3`0``L``0`-$AW"^1X`(`BV'Z
M_Y>``@`U7Q,`<:```%1:%P!1X,IZ.!^\`''!`0!4M09`^94!`+3@`Q6J"OO_
MEQ\,`/$)`0!4`!``T0$``+"@`@"+(?`OD4_Z_Y<?``!Q]Q*5FL#^_Y?`#``U
MX`,7J@$`@%)\^O^7]0,`*B`,`#1"`(!2(0*`DO<C!I$Z^O^7X0,7JN`#%2K"
M`(#2OOK_E^`C1CG`!0`UX"=&.1\,`7%A!0!4X"M&.1\$`7$!!0!4X"]&.1\,
M`7&A!`!4X#-&.1\@`7%!!`!4X#=&.1\4`7'A`P!40@"`4B$'@)+@`Q4J(?K_
ME^$#%ZK@`Q4J(@6`TJ7Z_Y<%``"PY`,7JJ70,I$!``"P`QLJD>(#%*HA!#"1
MX`,3JL3Z_Y?@`Q2JKOK_E^$#$ZK`NBF1?/S_E^`#$ZJG_O^79/__%Z`"0/E>
M_?^7]P,`JJ#T_[6C__\7`@"`4@$`@-+@`Q4J`_K_ER,%`)3Y`P"J`@"0TN$#
M%ZK@`Q4JA?K_E^(#`*H?``!Q+`,`5.`#%2KW8P61=_K_E_L#%ZKA`QFJ&0``
ML#E;+9$5`(#2^@,%D>`#&JI_!0"40FMU..`#%ZKA`QFJM08`D?<*`)&9^O^7
MOU(`\2'__U0%``"PY`,;JJ70,I'_`P8YR?__%^$#%ZK@`QFJ%P4`E-[__Q<!
M``"P````L"'T+)$`%"N1%P``L/=Z,)%$_/^7&!LJD=GY_Y<5``"PM=(RD>0#
M`"KE`Q6JXP,8JN(#%*K@`Q.J`0``L"%`,)%[^O^7X`,3J@$X@%)@^O^7'P0`
M,6'V_U19^O^7``!`N1]$`''A]?]4Q?G_ESD'`!'D`P`JY@,5JN4#&2KC`QBJ
MX@,4JN$#%ZK@`Q.J:/K_E^W__Q?]>[RI_0,`D?-3`:FS``#0]5L"J77>1_GW
M&P#YH`)`N5KZ_Y?T`P"JH`)`N5?Z_Y>!PD(Y`<0".0```+``I"J18OO_E\``
M`+0!`$`Y/\0`<6$``%0`!$`Y0```-+/]_Y=UWD?YH`)`N4CZ_Y=C`(!2(@"`
M4@$``+`AO#"1W_G_E_0#`*H@`@"TH`)`N3_Z_Y>!"D#Y`@``L$+$,)$A`$#Y
MWOG_EX`*0/D``$#Y``Q`N<``L#:@`D"Y-/K_EX$*0/DA`$#YG?G_EW?>1_FT
M``#PX`)`N2WZ_Y=C`(!2(@"`4@$``+`AV#"1Q/G_E_4#`*H``P"T````L`#<
M*9$S^_^7]@,`J@`!`+3@`D"Y'_K_EZ$*0/GB`Q:J(0!`^;_Y_Y<,```4<_S_
ME_8#`*K@`D"Y]@0`M!7Z_Y>A"D#YX@,6JB$`0/FU^?^7X`,6JO_Y_Y=SWD?Y
M8`)`N0SZ_Y?U`P"J8`)`N0GZ_Y<B`(!2`0``L"'@,)%!^?^7`@``L.$#`*I"
M-#&1X`,5JJ3Y_Y=@`D"YD\("D?WY_Y<?Q`(Y````L`"X*9$)^_^78`H`^<`!
M`+5@!D#Y$/[_EV`*`/E``0"U````L`!,,9$\^?^7[_G_EX'"`I$B!$#YH0I`
M^4(`0/G.__\7E,("D0$X@%*`"D#YTOG_E^,#`"H?1`!Q(`$`5``$`!$?!`!Q
MR0``5("*0*D!`$#Y````L`#0,9$G^?^7\U-!J?5;0JGW&T#Y_7O$J,`#7];]
M>[ZI_0,`D?-3`:GS`P"J]_S_E^[\_Y?T`P"JGOW_E\`!`#2S`0"T8`)`.6`!
M`#0!``"PX`,4JB%L+9%:^?^7GP(`ZZ$``%3@`Q.J\U-!J?U[PJ@(^_\7\U-!
MJ?U[PJC``U_6_X,*T:$``-`%X`"1!^`!D?U[`*G]`P"1(>1'^2(`0/GB3P'Y
M`@"`TN)C`)'F`P*JH0!`N<9``)&DA$#X(0C`6L$`'_B!_&#3(QP(4R'<>-,A
M''"280`!JH/\:--C''B29.!$JB$`!*K!@!_X_P`%ZP'^_U0#"(!21"!`^6,$
M`'%!-$#Y0B``D46`7_@A``3*1`1`^80`!<HA``3*)/Q?TX$$`:HA?$"203P`
M^6'^_U0$'$"I*3./T@480:E)4*OR"!!`^8'\6]/C_$+3(10$JF-X!ZK"``7*
M;7Q`DD(`!XJJ`07*0@`&RDH!!(I!0"&+2@$%RN(/0/E*`0:+ZQ=`^4(`"8LA
M``*+XA-`^2$`"`MK`0F+0@`)BTH!`HLB_%O30A0!JDH!`@N"_$+30G@$JF,`
M`LI,?$"28P`!BF,`#<IC``6+8P`+BTO]6]-K%0JJ8P`+"RO\0M-A>0&J0@`!
MRBM\0))"``J*0@`,RD(`#8OM&T#YK0$)BT(`#8MM_%O3K14#JD(`#0M-_4+3
MJGD*JB$`"LI-?4"2(0`#BB$`"\HA``R+[!]`^8P!"8LA``R+3/Q;TXP5`JHA
M``P+;/Q"TX-Y`ZI*`0/*;'Q`DDH!`HI*`0W*2@$+B^LC0/EK`0F+2@$+BRO\
M6]-K%0&J2@$+"TO\0M-B>0*J8P`"RDM\0))C``&*8P`,RF,`#8OM)T#YK0$)
MBV,`#8M-_5O3K14*JF,`#0LM_$+3H7D!JD(``<HN?$"20@`*BD(`"\I"``R+
M["M`^8P!"8M"``R+;/Q;TXP5`ZI"``P+3/U"TXIY"JHA``K*37U`DB$``XHA
M``[*(0`+B^LO0/EK`0F+(0`+BTO\6]-K%0*J(0`+"VO\0M-C>0.J2P$#RFQ\
M0)+J,T#Y:P$"BFL!#<I*`0F+:P$.BVL!"HLJ_%O32A4!JFL!"@M*_$+30GD"
MJF,``LI*?$"28P`!BF,`#,IC``V+[3=`^:T!"8MC``V+;?U;TZT5"ZIC``T+
M+?Q"TZ%Y`:I"``'*+7Q`DD(`"XI"``K*0@`,B^P[0/F,`0F+0@`,BVS\6].,
M%0.J0@`,"VS]0M.+>0NJ(0`+RFQ]0)(A``.*(0`-RB$`"HOJ/T#Y2@$)BR$`
M"HM*_%O32A4"JB$`"@MJ_$+32GD#JF,!"LI.?4"2ZT-`^6,``HIC``S*:P$)
MBV,`#8MC``N+*_Q;TVL5`:IC``L+2_Q"TVMY`JI"`0O*;7U`DNI'0/E"``&*
M0@`.RDH!"8M"``R+0@`*BVK\6]-*%0.J0@`*"RK\0M-*>0&J80$*RDQ]0)+K
M2T#Y(0`#BB$`#<IK`0F+(0`.BR$`"XM+_%O3:Q4"JB$`"PMK_$+38WD#JDH!
M`\IK?$"22@$"BDH!#,I*`0V+[4]`^:T!"8M*`0V++?Q;TZT5`:I*`0T+3?Q"
MTZ)Y`JIC``+*37Q`DF,``8IC``O*8P`,B^Q30/F,`0F+8P`,BTS]6].,%0JJ
M8P`,"RS\0M.!>0&J0@`!RF_\6]-"``J*[Q4#JD(`#<HL?$"20@`+B^M70/EK
M`0F+0@`+BU!`+XOO`0(+0OU"TTIX"JKN_5O3(0`*RLX5#ZKB6T#Y(0`#BB$`
M#,I"``F+(0`-BVW\0M,A``*+K7D#JC%`+HOB7T#Y2P$-RLX!`0MK`1!*(72=
MTFL!#(LAVZWRZ?U"TT(``8LI>0^J:P$"B\+]6].C`0G*0A0.JF,`$4IP02*+
M0@`+"VM`*HOC8T#Y3/Q;TXP5`JIC``&+:P$#B\/]0M-O02R+8W@.JHP!"PLJ
M`0/*ZV=`^4H!$$I*02V+:P$!BTH!"XN+_5O3:Q4,JDY!*XMK`0H+2OQ"TT)Y
M`JIJ``+*2@$/2DE!*8OJ:T#Y2@$!BRD!"HMJ_5O32A4+JBU!*HM*`0D+B?U"
MTRQY#*I)``S**0$.2B-!(XOI;T#Y*0$!BV,`"8M)_5O3*14*JFY`*8LI`0,+
M8_U"TVMX"ZJ#`0O*8P`-2F)`(HOC<T#Y8P`!BT(``XLC_5O38Q0)JDU`(XMC
M``(+0OU"TTIX"JIB`0K*0@`.2DQ`+(OB=T#Y0@`!BXP!`HMB_%O30A0#JHY!
M(HM"``P++/U"TXEY":I,`0G*C`$-2HM!*XOL>T#YC`$!BVL!#(M,_%O3C!4"
MJFU!+(N,`0L+:_Q"TV-Y`ZHK`0/*:P$.2FI!*HOK?T#Y:P$!BTH!"XN+_5O3
M:Q4,JDY!*XMK`0H+2OQ"TT)Y`JIJ``+*2@$-2DE!*8OJ@T#Y2@$!BRD!"HMJ
M_5O32A4+JBU!*HM*`0D+B?U"TRQY#*I)``S**0$.2B-!(XOIAT#Y*0$!BV,`
M"8M)_5O3*14*JFY`*8LI`0,+8_U"TVMX"ZJ#`0O*8P`-2F)`(HOCBT#Y8P`!
MBT(``XLC_5O38Q0)JDU`(XMC``(+0OU"TTIX"JIB`0K*0@`.2DQ`+(OBCT#Y
M0@`!BXP!`HMB_%O30A0#JHY!(HM"``P++/U"TXEY":I,`0G*C`$-2HM!*XOL
MDT#YC`$!BVL!#(M,_%O3C!4"JFU!+(N,`0L+:_Q"TV-Y`ZHK`0/*:P$.2FI!
M*HOKET#Y:P$!BTH!"XN+_5O3:Q4,JD]!*XMK`0H+2OQ"TT)Y`JIJ``+*2@$-
M2DE!*8OJFT#Y2@$!BRD!"HMJ_5O32A4+JDT!"0LN02J+B?U"TRQY#*JJ_5O3
M20`,RDH5#:HI`0]*(T$CB^F?0/DI`0&+8P`)BV]`*HM*`0,+8_U"TVMX"ZI)
M_5O3@P$+RBD5"JIC``Y*8D`BB^.C0/EC``&+0@`#BTY`*8LI`0(+HOU"TTUX
M#:IB`0W*0@`/2D-`+(OBIT#Y[*]`^4(``8MC``*+(OU;TT(4":IC``(+0OU"
MTTIX"JJB`0K*0@`.2D)`*XOKJT#Y80$!BT(``8MA_%O3(10#JD(``0LA_4+3
M*7@)JDL!":HA`0H*:P$#BFL!`:IA02V+BYN7TFOCL?*,`0N+(0`,BTS\6].,
M%0*J(0`,"VS\0M.#>0.J+`$#JFT`"0J,`0**C`$-JHI!*HOLLT#YC`$+BTH!
M#(LL_%O3C!4!JDH!#`M,_$+3@GD"JFP``JI-``,*C`$!BHP!#:J)02F+[+=`
M^8P!"XLI`0R+3/U;TXP5"JHI`0P++/Q"TX%Y`:I,``&J+0`""HP!"HJ,`0VJ
M@T$CB^R[0/F,`0N+8P`,BRS]6].,%0FJ8P`,"TS]0M.*>0JJ+``*JDT!`0J,
M`0F*C`$-JH)!(HOLOT#YC`$+BT(`#(ML_%O3C!4#JD(`#`LL_4+3B7D)JDP!
M":HM`0H*C`$#BHP!#:J!02&+[,-`^8P!"XLA``R+3/Q;TXP5`JHA``P+;/Q"
MTX-Y`ZHL`0.J;0`)"HP!`HJ,`0VJBD$JB^S'0/F,`0N+2@$,BRS\6].,%0&J
M2@$,"TS\0M.">0*J;``"JDT``PJ,`0&*C`$-JHE!*8OLRT#YC`$+BRD!#(M,
M_5O3C!4*JBD!#`LL_$+3@7D!JDP``:HM``(*C`$*BHP!#:J#02.+[,]`^8P!
M"XMC``R++/U;TXP5":IC``P+3/U"TXIY"JHL``JJ30$!"HP!"8J,`0VJ@D$B
MB^S30/F,`0N+0@`,BVS\6].,%0.J0@`,"RS]0M.)>0FJ3`$)JBT!"@J,`0.*
MC`$-JH%!(8OLUT#YC`$+BR$`#(M,_%O3C!4"JB$`#`ML_$+3@WD#JBP!`ZIM
M``D*C`$"BHP!#:J*02J+[-M`^8P!"XM*`0R++/Q;TXP5`:I*`0P+3/Q"TX)Y
M`JIL``*J30`#"HP!`8J,`0VJB4$IB^S?0/F,`0N+*0$,BTS]6].,%0JJ*0$,
M"RS\0M.!>0&J3``!JBT``@J,`0J*C`$-JH-!(XOLXT#YC`$+BV,`#(LL_5O3
MC!4)JF,`#`M,_4+3BGD*JBP`"JI-`0$*C`$)BHP!#:J"02*+[.=`^8P!"XM"
M``R+;/Q;TXP5`ZI"``P++/U"TXEY":I,`0FJ+0$*"HP!`XJ,`0VJ@4$AB^SK
M0/F,`0N+(0`,BTS\6].,%0*J(0`,"VS\0M.#>0.J+`$#JFT`"0J,`0**C`$-
MJHI!*HOL[T#YC`$+BTH!#(LL_%O3C!4!JDH!#`M,_$+3@GD"JFP``JI-``,*
MC`$!BHP!#:J)02F+[/-`^8P!"XLI`0R+3/U;TXP5"JHI`0P++/Q"TXUY`:I,
M``VJH0$""HP!"HJ,`0&JX?=`^8-!(XLL_5O3(0`+BXP5":IC``&+0?U"TRIX
M"JJ/`0,+<$`LBZ,!"JI!`0T*8P`)BF,``:KA^T#Y8D`BB^/]6]-C%`^J(0`+
MBT(``8LA_4+3;@`""RMX":I10".+00$+RN+_0/DA`!!*S/U;T\,ZF-)#3+GR
MC!4.JD(``XLA0"V+(0`"BXD!`0LP0"R+X?U"TR)X#ZHL_5O380$"RHP5":HA
M`!%*(4`JB^H#0?E*`0.+(0`*B\K]0M-*>0ZJ+4`LBX$!`0M,``K*C`$02HM!
M*XOL!T'YC`$#BVL!#(LL_%O3C!4!JFY!+(N,`0L+*_U"TVEY":I+`0G*:P$-
M2F)!(HOK"T'Y:P$#BT(`"XN+_5O3:Q4,JDU`*XMK`0(+(OQ"TT%X`:HB`0'*
M0@`.2DI`*HOB#T'Y0@`#BTH!`HMB_5O30A0+JDY!(HM"``H+BOU"TTQY#*HJ
M``S*2@$-2DE!*8OJ$T'Y2@$#BRD!"HM*_%O32A4"JBU!*HM*`0D+:?U"TRMY
M"ZJ)`0O**0$.2B%!(8OI%T'Y*0$#BR$`"8M)_5O3*14*JBY`*8LI`0$+0?Q"
MTR)X`JIA`0+*(0`-2BQ`+(OA&T'Y(0`#BXP!`8LA_5O3(10)JHU!(8LA``P+
M3/U"TXIY"JI,``K*C`$.2HM!*XOL'T'YC`$#BVL!#(LL_%O3C!4!JFY!+(N,
M`0L+*_U"TVEY":I+`0G*:P$-2F)!(HOK(T'Y:P$#BT(`"XN+_5O3:Q4,JDU`
M*XMK`0(+(OQ"TT%X`:HB`0'*0@`.2DI`*HOB)T'Y0@`#BTH!`HMB_5O30A0+
MJDY!(HM"``H+BOU"TTQY#*HJ``S*2@$-2DE!*8OJ*T'Y2@$#BRD!"HM*_%O3
M2A4"JBU!*HM*`0D+:?U"TRMY"ZJ)`0O**0$.2B%!(8OI+T'Y*0$#BR$`"8M)
M_5O3*14*JBY`*8LI`0$+0?Q"TR)X`JIA`0+*(0`-2BQ`+(OA,T'Y(0`#BXP!
M`8LA_5O3(10)JHU!(8LA``P+3/U"TXIY"JI,``K*C`$.2HM!*XOL-T'YC`$#
MBVL!#(LL_%O3C!4!JFY!+(N,`0L+*_U"TVEY":I+`0G*:P$-2F)!(HOK.T'Y
M:P$#BT(`"XN+_5O3:Q4,JDU`*XMK`0(+(OQ"TT%X`:HB`0'*0@`.2DI`*HOB
M/T'Y0@`#BTH!`HMB_5O30A0+JD]!(HM"``H+BOU"TTQY#*HJ``S*2@$-2H1`
M+(M)02F+ZD-!^4H!`XLI`0J+2OQ;TTH5`JI-`0D++D$JBVG]0M,K>0NJB0$+
MRBD!#THA02&+Z4=!^2D!`XLA``F+J?U;TRD5#:HA``D+2?Q"TR)Y`JIJ`0+*
M*?Q;TRD5`:I*`0Y**0$*BR$`!POJ2T'Y0@`&"P(,`/E#`0.+8P`$BR,!`PL#
M!`"IH?U"TR%X#:HA``4+`0@`^6$!"`L!$`#YH```L`#D1_GB3T'Y`0!`^4(`
M`>L!`(#20```5*/U_Y?]>T"I_X,*D<`#7];]>[^I`!"`TOT#`)'\]/^7'_P"
MJ2)@A-*BZ*SR`@``^2)QE=(?>`"YHOF]\@($`/G"GYO20A>S\@((`/G"CHK2
M0@:B\@(,`/D"/IS20GJX\@(0`/G]>\&HP`-?UOU[O*G]`P"1\U,!J?,#`*I`
M?$"3]5L"J?0#`*IB%D#Y]QL`^4,,``M?``/KB0``5&(:0/E"!`"18AH`^6(:
M0/EUX@"10'1`BV."`JE@>D"Y@`,`-!8(@%+6`@!+WP(4:Z#"((O6TI0:PGY`
MDQ\``>NB``!4`P`"BS\``^M"``!4`'T@U#<``HL?``'K:0``5!\`%^MC__]4
M5O7_EV!Z0+G``@`+8'H`N1\``7'!`@!4X`,3JHO[_Y>4`A9+X0,7JG?B`9&?
M_@!QC`(`5()^0),_`!7KB0``5*`"`HL_``#K`_W_5#\`%>N"``!4(``"B[\"
M`.MC_/]4X`,5JCWU_Y=T>@"Y\U-!J?5;0JGW&T#Y_7O$J,`#7]8_`!7K:0``
M5#\`%^OC^O]4-@`!D;\"`>MI``!4OP(6ZT/Z_U0@!$"MX`,3JI0"`5&@!@"M
M(`1!K:`&`:UC^_^7X0,6JMK__Q?]>[RIX@^`$OT#`)'S4P&I]`,`JO,#`:KU
M6P*I->``D?<;`/D@%$#Y-BA`N3<P0+D`(`-3U@K`6@$$`!'W"L!:HLH@.*#"
M(8L_X`!QC0D`5`((@%)"``%+`0"`4D)\0)-L]/^7X`,3JD;[_Y>_&@#Y``0`
M3Z`"`*V@"H`]X`,3JG=:#BD_^_^78`)`^0#\6-.``@`Y8`)`^0#\4-.`!@`Y
M8`)`^0#\2-.`"@`Y8`)`^8`.`#E@!D#Y`/Q8TX`2`#E@!D#Y`/Q0TX`6`#E@
M!D#Y`/Q(TX`:`#E@!D#Y@!X`.6`*0/D`_%C3@"(`.6`*0/D`_%#3@"8`.6`*
M0/D`_$C3@"H`.6`*0/F`+@`Y8`Y`^0#\6-.`,@`Y8`Y`^0#\4-.`-@`Y8`Y`
M^0#\2-.`.@`Y8`Y`^8`^`#E@$D#Y`/Q8TX!"`#E@$D#Y]5M"J0#\4-.`1@`Y
M8!)`^0#\2-.`2@`Y8!)`^8!.`#G@`Q.J\U-!J?<;0/G]>\2HKO3_%P('@%)"
M``%+`0"`4D)\0),A]/^7N___%_U[OZG]`P"1_7O!J,`#7]8N+@`E<R\E<P!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`
M4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%
M`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)
M3TX`,2XP-30`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`M90`M+0!54T52`%5315).04U%`%1%35!$25(`
M5$U0`"]T;7``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G
M+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B
M)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U
M:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1C:'5N:U]S:7IE(#T@
M-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US(%]&2#L*;7D@)&UA
M9VEC7W!O<R`]("1S:7IE("T@)'-I>F4@)2`D8VAU;FM?<VEZ93L@(R!.3U1%
M.B`D;6%G:6-?<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@
M,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0II9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T
M<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T
M85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]
M("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@
M9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^
M>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE
M("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T
M.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I
M;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@
M7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@
M=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN
M8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E
M>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F
M:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O
M*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0[
M"GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@
M*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,
M12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E
M9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@
M)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H
M:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D
M.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q
M,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A
M)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA
M;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@)&9H
M+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D<WES
M>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V
M86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI3
M2$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\
M?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD9&EG
M97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM
M>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M
M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@
M>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L
M("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T
M96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("````$;`SOP````'0````24__\,!0``%);__P@!
M``!$EO__'`$``(26__\P`0``Y);__U0!```8E___=`$``-27__^H`0``()C_
M_\@!``"TF/__\`$```B:__\H`@``F)K__TP"``!PG/__A`(``*B<__^D`@``
M_)S__\@"```PGO__^`(``#2>__\,`P``#*#__U`#```LH/__9`,``#2A__^D
M`P``U*+__]`#```LH___]`,``$RC__\4!````*3__TP$```,JO__K`0``$"L
M___<!```I*S__SP%``!HO?__8`4``,2]__^`!0``)+___[0%```0````````
M``%Z4@`$>!X!&PP?`!`````8````!)7__S``````````$````"P````@E?__
M/``````````@````0````$R5__]@`````$$.()T$G@-"DP)4WMW3#@`````<
M````9````(B5__\T`````$0.$)T"G@%'WMT.`````#````"$````G)7__[P`
M````00Y`G0B>!T23!I0%E026`Y<"F`%C"M[=U]C5UM/4#@!!"P`<````N```
M`"26__],`````$$.()T$G@-1WMT.`````"0```#8````4);__Y0`````00Y`
MG0B>!T*3!I0%1)4$7=[=U=/4#@`T``````$``+R6__]4`0```$$.X`&=')X;
M1Y,:E!F5&)87EQ:8%9D4`DS>W=G7V-76T]0.`````"`````X`0``V)?__Y``
M````00ZP`9T6GA5$DQ1>WMW3#@```#0```!<`0``1)C__]@!````00Y@G0R>
M"T*5")8'0Y,*E`E$EP:8!9D$`FO>W=G7V-76T]0.````'````)0!``#DF?__
M.`````!!#A"=`IX!1M[=#@`````@````M`$``/R9__]4`````$$.()T$G@-"
MDP)*WMW3#@`````L````V`$``"R:__\T`0```$(.T$!"G8H(GHD(0Y.(")2'
M"$*5A@@"0]W>U=/4#@`0````"`(``#";__\$`````````$`````<`@``()O_
M_]@!````0@[@(4&=G`2>FP1"DYH$E)D$1Y68!):7!)>6!)B5!)F4!)J3!`)I
MW=[9VM?8U=;3U`X`$````&`"``"TG/__(``````````\````=`(``,"<__\(
M`0```$(.()T$G@-"DP*4`4?>W=/4#@!!#B"3`I0!G02>`W`*WMW3U`X`00M"
M#@#3U-W>*````+0"``"(G?__H`$```!!#F"=#)X+1),*E`E"E0B6!P)@WMW5
MUM/4#@`@````X`(``/R>__]8`````$$.()T$G@-"DP)0"M[=TPX`00L<````
M!`,``#"?__\@`````$$.$)T"G@%&WMT.`````#0````D`P``,)___[0`````
M00XPG0:>!4*5`I8!0Y,$E`-,"M[=U=;3U`X`00M9WMW5UM/4#@``7````%P#
M``"LG___#`8```!"#I"#`D*=LB">L2!"E:X@EJT@0Y.P()2O($:7K""8JR"9
MJB":J2";J"!K"MW>V]G:U]C5UM/4#@!!"P)G"MW>V]G:U]C5UM/4#@!!"P``
M+````+P#``!8I?__-`(```!!#D"=")X'0I,&E`5"E026`T*7`@*%WMW7U=;3
MU`X`+````.P#``!<I___9`````!!#B"=!)X#0I,"E`%2"M[=T]0.`$$+0M[=
MT]0.````+````!P$``#PCO__R`$```!!#E"="IX)0I,(E`=#E08":`K>W=73
MU`X`00L`````(````$P$``!@I___Q!````!!#J`%1)U4GE,#*P3=W@X`````
M'````'`$````N/__7`````!!#A"=`IX!5=[=#@`````P````D`0``#RX__]@
M`0```$$.0)T(G@="DP:4!4:5!)8#EP)\"M[=U]76T]0.`$$+````,````,0$
M``!HN?__E`$```!!#D"=")X'0Y,&E`5#E026`T*7`@)5"M[=U]76T]0.`$$+
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$`@````````X!\````````!`````````/H"`````````0``````
M```%`P````````\`````````4P0````````,`````````(`9````````#0``
M```````42@```````!D`````````F)L!```````;``````````@`````````
M&@````````"@FP$``````!P`````````"`````````#U_O]O`````"`"````
M````!0````````#(#`````````8`````````"`,````````*`````````'$$
M````````"P`````````8`````````!4````````````````````#````````
M`(B=`0```````@````````"(!0```````!0`````````!P`````````7````
M`````/@3````````!P````````!`$0````````@`````````N`(````````)
M`````````!@`````````&````````````````````/O__V\``````0``"```
M``#Y__]O`````!``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"0&0```````)`9````
M````D!D```````"0&0```````)`9````````D!D```````"0&0```````)`9
M````````D!D```````"0&0```````)`9````````D!D```````"0&0``````
M`)`9````````D!D```````"0&0```````)`9````````D!D```````"0&0``
M`````)`9````````D!D```````"0&0```````)`9````````D!D```````"0
M&0```````)`9````````D!D```````"0&0```````)`9````````D!D`````
M``"0&0```````)`9````````D!D```````"0&0```````)`9````````D!D`
M``````"0&0```````)`9````````D!D```````"0&0```````)`9````````
MD!D```````"0&0```````)`9````````D!D```````"0&0```````)`9````
M````D!D```````"0&0```````)`9````````D!D```````"0&0```````)`9
M````````D!D```````"0&0```````)`9````````D!D```````"0&0``````
M`)`9````````J)L!``````!@'0`````````````````````````````42@``
M``````````````````````````"`&0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P````#53````````"5*````````````
M```````&2P```````/]*````````R4P````````<2P```````-%,````````
M``````````"[3````````,!,``````````````````#:3````````$=#0SH@
M*$%L<&EN92`Q,2XR+C%?9VET,C`R,C`R,3DI(#$Q+C(N,2`R,#(R,#(Q.0``
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````
M````````````````````````````````````````````````````````````
M``````````````````L````!`````@```````````@`````````"````````
M&@````````````````````$````````````````````3````]O__;P(`````
M````(`(````````@`@```````.@``````````P`````````(````````````
M````````'0````L````"``````````@#````````"`,```````#`"0``````
M``0````#````"``````````8`````````"4````#`````@````````#(#```
M`````,@,````````<00```````````````````$````````````````````M
M````!`````(`````````0!$```````!`$0```````+@"`````````P``````
M```(`````````!@`````````-P````0```!"`````````/@3````````^!,`
M``````"(!0````````,````1````"``````````8`````````$$````!````
M!@````````"`&0```````(`9````````$`````````````````````0`````
M```````````````\`````0````8`````````D!D```````"0&0```````-`#
M```````````````````0````````````````````1P````$````&````````
M`&`=````````8!T```````"T+```````````````````$```````````````
M`````$T````!````!@`````````42@```````!1*````````$```````````
M``````````0```````````````````!3`````0````(`````````)$H`````
M```D2@```````#@_```````````````````!````````````````````6P``
M``$````"`````````%R)````````7(D```````#T````````````````````
M!````````````````````&D````!`````@````````!0B@```````%"*````
M````^`0```````````````````@```````````````````!S````#@````,`
M````````F)L!``````"8FP````````@````````````````````(````````
M``@`````````?P````\````#`````````*";`0``````H)L````````(````
M````````````````"``````````(`````````(L````&`````P````````"H
MFP$``````*B;````````X`$````````$``````````@`````````$```````
M``"4`````0````,`````````B)T!``````"(G0```````'@"````````````
M```````(``````````@`````````F0````$````#``````````"@`0``````
M`*````````!X````````````````````"````````````````````)\````(
M`````P````````!XH`$``````'B@````````6!````````````````````@`
M``````````````````"D`````0```#````````````````````!XH```````
M`#$````````````````````!``````````$``````````0````,`````````
M````````````````J:````````"M`````````````````````0``````````
'````````````
